# CHANGELOG

## 0.0.13 (11-01-2017)
- Fix install package via pip!

## 0.0.12 (06-01-2017)
- Fix tests to python 2.6

## 0.0.11 (05-01-2017)
- Fix compatibility list in pypi
- Add python 3.6 to tests in travis

## 0.0.10 (05-01-2017)
- Add tests
- Travis integration
- Coverage 100%
- Full support python 2.7 and Pypy

## 0.0.9 (05-01-2017)
- Support python 2 (https://github.com/agalera/bottlejwt/pull/1) by stryker250

## 0.0.1 to 0.0.8
- Initial version
